==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/igc-geographic-marker-series-component.js <==
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
/**
 * Base class for creating marker series in a IgxGeographicMap.Component
*/
export let IgcGeographicMarkerSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicMarkerSeriesComponent extends IgcGeographicMapSeriesHostComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicMarkerSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent = names;
            }
            return IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent;
        }
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get markerType() {
            return this.i.uf;
        }
        set markerType(v) {
            this.i.uf = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.uf));
        }
        /**
         * Gets or sets thickness of the marker outline
        */
        get markerThickness() {
            return this.i.ug;
        }
        set markerThickness(v) {
            this.i.ug = +v;
            this._a("markerThickness", this.i.ug);
        }
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get markerOutlineMode() {
            return this.i.ue;
        }
        set markerOutlineMode(v) {
            this.i.ue = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.ue));
        }
        /**
         * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
        */
        get markerFillMode() {
            return this.i.ud;
        }
        set markerFillMode(v) {
            this.i.ud = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.ud));
        }
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get markerTemplate() {
            return this.i.uv;
        }
        set markerTemplate(v) {
            this.i.uv = v;
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get markerBrush() {
            return brushToString(this.i.u9);
        }
        set markerBrush(v) {
            this.i.u9 = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.u9));
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get markerOutline() {
            return brushToString(this.i.va);
        }
        set markerOutline(v) {
            this.i.va = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.va));
        }
        /**
         * Gets or sets the maximum number of markerItems displayed by the current series.
         * If more than the specified number of markerItems are visible, the series will automatically
         * choose a representative set.
        */
        get maximumMarkers() {
            return this.i.uh;
        }
        set maximumMarkers(v) {
            this.i.uh = +v;
            this._a("maximumMarkers", this.i.uh);
        }
        /**
         * Gets the effective marker template for the current series object.
        */
        get actualMarkerTemplate() {
            return this.i.uu;
        }
        set actualMarkerTemplate(v) {
            this.i.uu = v;
        }
        /**
         * Gets the effective marker brush for the current series object.
        */
        get actualMarkerBrush() {
            return brushToString(this.i.u7);
        }
        set actualMarkerBrush(v) {
            this.i.u7 = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.u7));
        }
        /**
         * Gets the effective marker outline for the current series object.
        */
        get actualMarkerOutline() {
            return brushToString(this.i.u8);
        }
        set actualMarkerOutline(v) {
            this.i.u8 = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.u8));
        }
    }
    IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent = null;
    return IgcGeographicMarkerSeriesComponent;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/igc-geographic-marker-series-component.js <==
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString, brushToString, stringToBrush } from "igniteui-webcomponents-core";
/**
 * Base class for creating marker series in a IgxGeographicMap.Component
*/
export let IgcGeographicMarkerSeriesComponent = /*@__PURE__*/ (() => {
    class IgcGeographicMarkerSeriesComponent extends IgcGeographicMapSeriesHostComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent == null) {
                let names = getAllPropertyNames(IgcGeographicMarkerSeriesComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent = names;
            }
            return IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent;
        }
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get markerType() {
            return this.i.xc;
        }
        set markerType(v) {
            this.i.xc = ensureEnum(MarkerType_$type, v);
            this._a("markerType", enumToString(MarkerType_$type, this.i.xc));
        }
        /**
         * Gets or sets thickness of the marker outline
        */
        get markerThickness() {
            return this.i.xd;
        }
        set markerThickness(v) {
            this.i.xd = +v;
            this._a("markerThickness", this.i.xd);
        }
        /**
         * Gets or sets whether the marker outline is based on the marker brush of the series rather than the marker outlines collection.
        */
        get markerOutlineMode() {
            return this.i.xb;
        }
        set markerOutlineMode(v) {
            this.i.xb = ensureEnum(MarkerOutlineMode_$type, v);
            this._a("markerOutlineMode", enumToString(MarkerOutlineMode_$type, this.i.xb));
        }
        /**
         * Gets or sets whether the marker fill is based on the marker outline of the series rather than the marker brushes collection.
        */
        get markerFillMode() {
            return this.i.xa;
        }
        set markerFillMode(v) {
            this.i.xa = ensureEnum(MarkerFillMode_$type, v);
            this._a("markerFillMode", enumToString(MarkerFillMode_$type, this.i.xa));
        }
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get markerTemplate() {
            return this.i.xs;
        }
        set markerTemplate(v) {
            this.i.xs = v;
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get markerBrush() {
            return brushToString(this.i.x6);
        }
        set markerBrush(v) {
            this.i.x6 = stringToBrush(v);
            this._a("markerBrush", brushToString(this.i.x6));
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get markerOutline() {
            return brushToString(this.i.x7);
        }
        set markerOutline(v) {
            this.i.x7 = stringToBrush(v);
            this._a("markerOutline", brushToString(this.i.x7));
        }
        /**
         * Gets or sets the maximum number of markerItems displayed by the current series.
         * If more than the specified number of markerItems are visible, the series will automatically
         * choose a representative set.
        */
        get maximumMarkers() {
            return this.i.xe;
        }
        set maximumMarkers(v) {
            this.i.xe = +v;
            this._a("maximumMarkers", this.i.xe);
        }
        /**
         * Gets the effective marker template for the current series object.
        */
        get actualMarkerTemplate() {
            return this.i.xr;
        }
        set actualMarkerTemplate(v) {
            this.i.xr = v;
        }
        /**
         * Gets the effective marker brush for the current series object.
        */
        get actualMarkerBrush() {
            return brushToString(this.i.x4);
        }
        set actualMarkerBrush(v) {
            this.i.x4 = stringToBrush(v);
            this._a("actualMarkerBrush", brushToString(this.i.x4));
        }
        /**
         * Gets the effective marker outline for the current series object.
        */
        get actualMarkerOutline() {
            return brushToString(this.i.x5);
        }
        set actualMarkerOutline(v) {
            this.i.x5 = stringToBrush(v);
            this._a("actualMarkerOutline", brushToString(this.i.x5));
        }
    }
    IgcGeographicMarkerSeriesComponent._observedAttributesIgcGeographicMarkerSeriesComponent = null;
    return IgcGeographicMarkerSeriesComponent;
})();
